#!/bin/bash

# This is svg2icons version 0.1
# by Dan Leinir Turthra Jensen ( admin (at) leinir.dk )
# The script is released under the GPL ( http://www.gnu.org/copyleft/ )
#
#  It is a script designed to perform the simple but tedious task of converting
# images from SVG (or any arbitrary image format supported by ImageMagic's
# convert) into a 960x960 PNG and then scale the image down, placing them in the
# correct directory structure for use as a KDE icon set.
#
# Usage:
#  svg2icons [-s] filename section [ext]
#  svg2icons -h
#
#  Where...
#   filename is the filename minus extension (no path)
#   section is the section name (can be any of actions, apps, devices,
#      filesystems and mimetypes (plus any other, but these are the basic KDE
#      sections))
#   ext (optional) is the file extension of the original image. If this is not
#      present svg2icons will assume it is svg. Note that this is case sensitive
#   -s (optional) means that the original image is in the correct directory
#      structure (i.e. for an icon called stop in the subfolder scaled/actions
#      under the working folder in stead of at the root of it)
#
# examples of usage:
#
#  The command:
#    svg2icons -s stop actions
#  Will use the file:
#    ./scalable/actions/stop.svg
#  Will create the following icons:
#    ./16x16/actions/stop.png
#    ./22x22/actions/stop.png
#    ./32x32/actions/stop.png
#    ./48x48/actions/stop.png
#    ./64x64/actions/stop.png
#    ./128x128/actions/stop.png
#
#   The command:
#    svg2icons konqeror apps JPG
#   Will use the file:
#    ./konqueror.JPG
#   Will create the following icons:
#    ./16x16/apps/konqueror.png
#    ./22x22/apps/konqueror.png
#    ./32x32/apps/konqueror.png
#    ./48x48/apps/konqueror.png
#    ./64x64/apps/konqueror.png
#    ./128x128/apps/konqueror.png

echo "
*******************************************************************************
This is svg2icons                                                   version 0.1
                                                   by Dan Leinir Turthra Jensen
*******************************************************************************
"


#------------------------------------------------
# Show usage instructions
if [ "$1" = "-h" -o "$1" = "" ]; then
  echo "It is a script designed to perform the simple but tedious task of converting
images from SVG (or any arbitrary image format supported by ImageMagic's
convert) into a 960x960 PNG and then scale the image down, placing them in the
correct directory structure for use as a KDE icon set.

Usage:
  svg2icons [-s] filename section [ext]
  scg2icons -h (for this help screen)

 Where...
  filename is the filename minus extension (no path)
  section is the section name (can be any of actions, apps, devices, filesystems
     and mimetypes (plus any other, but these are the basic KDE sections))
  ext (optional) is the file extension of the original image. If this is not
     present svg2icons will assume it is svg. Note that this is case sensitive
  -s (optional) means that the original image is in the correct directory
     structure (i.e. for an icon called stop in the subfolder scaled/actions
     under the working folder in stead of at the root of it)
"
   exit 1

#------------------------------------------------
# Work with original icon in the correct path
elif [ "$1" = "-s" ]; then
  echo -s detected, using correct directory structure
  if [ "$2" = "" ]; then
    echo Icon name missing. For help use the switch -h.
    exit 0
  fi
  if [ "$3" = "" ]; then
    echo Section name missing. For help use the switch -h.
    exit 0
  fi
  if [ "$4" = "" ]; then
    OriginalIcon="$PWD/scalable/$3/$2.svg"
    OriginalExtension="svg"
  else
    OriginalIcon="$PWD/scalable/$3/$2.$4"
    OriginalExtension="$4"
  fi
  IconName="$2"
  IconSection="$3"

#------------------------------------------------
# Work with original icon in the base path
else
  echo -s not detected, looking in base path for original icon
  if [ "$1" = "" ]; then
    echo Icon name missing. For help use the switch -h.
    exit 0
  fi
  if [ "$2" = "" ]; then
    echo Section name missing. For help use the switch -h.
    exit 0
  fi
  if [ "$3" = "" ]; then
    OriginalIcon="$PWD/$1.svg"
    OriginalExtension="svg"
  else
    OriginalIcon="$PWD/$1.$3"
    OriginalExtension="$3"
  fi
  IconName="$1"
  IconSection="$2"
fi

if [ "$OriginalExtension" = "svg" ]; then
 echo Now exporting from SVG to PNG using Sodipodi
 sodipodi --without-gui --file=$OriginalIcon --export-png=$PWD/temp.png --export-width=960 --export-height=960 > ~/svg2icons.log
else
 echo Now converting from $OriginalExtension to PNG using ImageMagik\'s convert
 convert $OriginalIcon -resize 960x960 -antialias $PWD/temp.png > ~/svg2icons.log
fi
echo Creating 16x16 icon...
mkdir -p $PWD/16x16/$IconSection
convert $PWD/temp.png -resize 16x16 -antialias $PWD/16x16/$IconSection/$IconName.png >> ~/svg2icons.log
echo Creating 22x22 icon...
mkdir -p $PWD/22x22/$IconSection
convert $PWD/temp.png -resize 22x22 -antialias $PWD/22x22/$IconSection/$IconName.png >> ~/svg2icons.log
echo Creating 32x32 icon...
mkdir -p $PWD/32x32/$IconSection
convert $PWD/temp.png -resize 32x32 -antialias $PWD/32x32/$IconSection/$IconName.png >> ~/svg2icons.log
echo Creating 48x48 icon...
mkdir -p $PWD/48x48/$IconSection
convert $PWD/temp.png -resize 48x48 -antialias $PWD/48x48/$IconSection/$IconName.png >> ~/svg2icons.log
echo Creating 64x64 icon...
mkdir -p $PWD/64x64/$IconSection
convert $PWD/temp.png -resize 64x64 -antialias $PWD/64x64/$IconSection/$IconName.png >> ~/svg2icons.log
echo Creating 128x128 icon...
mkdir -p $PWD/128x128/$IconSection
convert $PWD/temp.png -resize 128x128 -antialias $PWD/128x128/$IconSection/$IconName.png >> ~/svg2icons.log
echo Cleaning up...
rm -f $PWD/temp.png >> ~/svg2icons.log
echo Done!
